pub struct BootMapping {
pub virt: VirtAddr,
pub phys: PhysAddr,
pub size: u64,
pub flags: VmaFlags,
pub can_overmap: bool,
}Expand description
A data structure to define a memory mapping for when its definition needs to be remembered briefly (like when VMAs and pages get build at different times)
Fields
virt: VirtAddrphys: PhysAddrsize: u64flags: VmaFlagscan_overmap: bool